<?php
/**
 * Functions for EDD Software Licensing
 *
 * @package   Caldera_Easy_Pods
 * @author    Josh Pollock <Josh@JoshPress.net>
 * @license   GPL-2.0+
 * @link      
 * @copyright 2015 CalderaWP
 */


/**
 * Process the license activation or deactivation
 *
 * @uses 'wp_ajax_cep_save_license' action
 *
 * @since 0.2.0
 */
add_action( 'wp_ajax_cep_save_license', 'cep_license_update' );
function cep_license_update() {
	$license_data = false;
	$data = pods_sanitize( $_POST );

	$error_response = array(
		'success' => false,
		'message' => __( 'License Could Not Be Processed. Please try again' ),
	);

	if ( ! wp_verify_nonce(  $data[ 'cep_license_nonce' ], 'cep_license_nonce' ) ){
		wp_send_json_error( $error_response );
	}

	if ( isset( $data[ 'code'] ) ) {
		$code = $data[ 'code' ];
		if ( isset( $data[ 'license_action' ] ) ) {
			if ( 'activate' === $data[ 'license_action' ]  ) {
				$license_data = cep_license_activate_license( $code );
			} else {
				$license_data = cep_license_deactivate_license( $code );
			}
		}

		if ( is_object( $license_data ) ) {
			update_option( CEP_LICENSE_KEY_OPTION_NAME, $code );
			if ( $license_data->success ) {
				wp_send_json_success( $license_data );
			}else{
				wp_send_json_error( $license_data );
			}

		}

		wp_send_json_error( $error_response );

	}




}
/**
 * Activate License
 *
 * @uses 'admin_init' action
 *
 * @since 0.2.0
 *
 * @return bool|void
 */
function cep_license_activate_license( $code ) {
	$response = cep_license_api_request( 'activate_license' );

	if ( is_wp_error( $response ) ) {
		return false;
	}

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );

	update_option( CEP_LICENSE_STATUS_KEY_OPTION_NAME, $license_data->license );

	return $license_data;

}

/**
 * Deactivate license
 *
 * @since 0.2.0
 *
 * @return bool|void
 */
function cep_license_deactivate_license( $code ) {
	$response = cep_license_api_request( 'deactivate_license' );

	if ( is_wp_error( $response ) ) {
		return false;
	}

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );


	if( $license_data->license == 'deactivated' ) {
		 delete_option( CEP_LICENSE_STATUS_KEY_OPTION_NAME );
	}

	return $license_data;

}


/**
 * Register option for the license key
 *
 * @since 0.2.0
 *
 * @uses 'admin_init' action
 */
function cep_license_register_option() {
	register_setting( 'cep_licenses', CEP_LICENSE_KEY_OPTION_NAME, 'cep_license_sanitize_license' );
}


/**
 * Sanitization callback for register_setting() used in cep_license_register_option()
 *
 * @since 0.2.0
 *
 * @param string $new The new license key.
 *
 * @return mixed|bool|string
 */
function cep_license_sanitize_license( $new ) {
	$old = get_option( CEP_LICENSE_KEY_OPTION_NAME );
	if( $old && $old != $new ) {
		delete_option( CEP_LICENSE_STATUS_KEY_OPTION_NAME);
	}

	return $new;

}

/**
 * Check a license.
 *
 * @since 0.2.0
 *
 * @return bool
 */
function cep_license_check_license() {

	global $wp_version;

	$response = cep_license_api_request( 'check_license' );

	if ( is_wp_error( $response ) ) {
		return false;

	}

	$license_data = json_decode( wp_remote_retrieve_body( $response ) );

	if( $license_data->license == 'valid' ) {
		echo 'valid';
		exit;

	} else {
		echo 'invalid';
		exit;

	}

}

/**
 * Make request to licensing API
 *
 * @since 0.2.0
 *
 * @param string $edd_action
 *
 * @return array|\WP_Error
 */
function cep_license_api_request( $edd_action ) {
	$license = trim( get_option( CEP_LICENSE_KEY_OPTION_NAME ) );


	$api_params = array(
		'edd_action'=> $edd_action,
		'license' 	=> $license,
		'item_name' => urlencode( CEP_PRODUCT_NAME ),
		'url'       => home_url()
	);

	$url      = add_query_arg( $api_params, CWP_STORE_URL );
	$response = wp_remote_get(
		$url, array(
			'timeout'   => 15,
			'sslverify' => false
		)
	);

	return $response;

}

/**
 * Create a submit button for the licensing page.
 *
 * @since 0.2.0
 *
 * @param $status
 *
 * @return string
 */
function cep_license_submit_button( $status ) {

	if ( cep_is_license_valid() ) {
		$license_action = 'activate';
		$value = __( 'Activate License', 'easy-pods' );
	}else{
		$license_action = 'deactivate';
		$value = __( 'Deactivate License', 'easy-pods' );
	}

	$nonce_field = wp_nonce_field( 'cep_license_nonce', 'cep_license_nonce', true, false );

	return sprintf( '%0s<input type="submit" id="code-submit" class="wp-baldrick add-new-h2" data-action="cep_save_license" data-license_action="%1s" data-before="cep_license_before" data-cep_license_nonce="false" data-code="false" data-callback="cep_license_cb" value="%2s"/>', $nonce_field, esc_attr( $license_action ), esc_attr( $value ) );

}

/**
 * Check if license is valid.
 *
 * @since 0.2.0
 *
 * @return bool
 */
function cep_is_license_valid() {
	$status  = get_option( CEP_LICENSE_STATUS_KEY_OPTION_NAME, false );
	if ( false == $status || 'invalid' == $status ) {
		return false;
	}

	return true;

}
